///////////////////////////////////////////////////////////////////////////////////
// GameStudio main script
////////////////////////////////////////////////////////////////////////////
// Files to over-ride:
// * logodark.bmp - the engine logo, include your game title
// * horizon.pcx - A horizon map displayed over the sky and cloud maps
////////////////////////////////////////////////////////////////////////////
// The PATH keyword gives directories where game files can be found,
// relative to the level directory
path "C:\\Programme\\GStudio6\\template";	// Path to WDL templates subdirectory

////////////////////////////////////////////////////////////////////////////
// The INCLUDE keyword can be used to include further WDL files,
// like those in the TEMPLATE subdirectory, with prefabricated actions
include <movement.wdl>;
include <messages.wdl>;
include <menu.wdl>;		// must be inserted before doors and weapons
include <particle.wdl>; // remove when you need no particles
include <doors.wdl>;		// remove when you need no doors
include <actors.wdl>;   // remove when you need no actors
include <weapons.wdl>;  // remove when you need no weapons
include <war.wdl>;      // remove when you need no fighting
//include <venture.wdl>;	// include when doing an adventure
include <lflare.wdl>;   // remove when you need no lens flares
include <controls.wdl>;
////////////////////////////////////////////////////////////////////////////
// The engine starts in the resolution given by the follwing vars.
var video_mode = 10;	 // screen size 640x480
var video_depth = 16; // 16 bit colour D3D mode

/////////////////////////////////////////////////////////////////
// Strings and filenames
// change this string to your own starting mission message.
string mission_str = "Fight your way through the level until evacuations point and collect all weapons !. Press [esc] for menu";
string level_str = <level1.WMB>; // give file names in angular brackets

/////////////////////////////////////////////////////////////////
// define a splash screen with the required A4/A5 logo
bmap splashmap = <logo.bmp>; // the default logo in templates
panel splashscreen {
	bmap = splashmap;
	flags = refresh,d3d;
}


bmap splashmap1 = <logo1.bmp>; // the default logo in templates
panel splashscreen1 {
	bmap = splashmap1;
	flags = refresh,d3d;
}

bmap splashmap2 = <screen1.bmp>; // the default logo in templates
panel splashscreen2 {
	bmap = splashmap2;
	flags = refresh,d3d;
}


////////////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////
// The main() function is started at game start
function main()
{
	init_controls();
// some common flags and variables
//	warn_level = 2;	// announce bad texture sizes and bad wdl code
	tex_share = on;	// map entities share their textures

   splashscreen.pos_x = (screen_size.x - bmap_width(splashmap))/2;
	splashscreen.pos_y = (screen_size.y - bmap_height(splashmap))/2;
	splashscreen.visible = on;
   wait(3);
   sleep(2);
  	splashscreen.visible = off;
	bmap_purge(splashmap);
	
	splashscreen1.pos_x = (screen_size.x - bmap_width(splashmap))/2;
	splashscreen1.pos_y = (screen_size.y - bmap_height(splashmap))/2;
	splashscreen1.visible = on;
   wait(3);
   sleep(2);
  	splashscreen1.visible = off;
	bmap_purge(splashmap1);
	

// center the splash screen for non-640x480 resolutions, and display it
	splashscreen2.pos_x = (screen_size.x - bmap_width(splashmap))/2;
	splashscreen2.pos_y = (screen_size.y - bmap_height(splashmap))/2;
	splashscreen2.visible = on;
// wait 3 frames (for triple buffering) until it is flipped to the foreground
	wait(3);

// now load the level
	level_load(level_str);
// freeze the game
	freeze_mode = 1;

// wait the required second, then switch the splashscreen off.
	sleep(40);
  	splashscreen2.visible = off;
	bmap_purge(splashmap2);	// remove splashscreen from video memory

// load some global variables, like sound volume
	load_status();

// display the initial message
	msg_show(mission_str,10);

// initialize lens flares when edition supports flares
ifdef CAPS_FLARE;
	lensflare_start();
endif;

// use the new 3rd person camera
	move_view_cap = 1;

// un-freeze the game
	freeze_mode = 0;

//	client_move();	// for a possible multiplayer game
// call further functions here...
   targetstart();
   startcompass();
   ismeniu();
}


/////////////////////////////////////////////////////////////////
// The following definitions are for the pro edition window composer
// to define the start and exit window of the application.
WINDOW WINSTART
{
	TITLE			"3D GameStudio";
	SIZE			480,320;
	MODE			IMAGE;	//STANDARD;
	BG_COLOR		RGB(240,240,240);
	FRAME			FTYP1,0,0,480,320;
//	BUTTON		BUTTON_START,SYS_DEFAULT,"Start",400,288,72,24;
	BUTTON		BUTTON_QUIT,SYS_DEFAULT,"Abort",400,288,72,24;
	TEXT_STDOUT	"Arial",RGB(0,0,0),10,10,460,280;
}


/* no exit window at all..
WINDOW WINEND
{
	TITLE			"Finished";
	SIZE			540,320;
	MODE	 		STANDARD;
	BG_COLOR		RGB(0,0,0);
	TEXT_STDOUT	"",RGB(255,40,40),10,20,520,270;

	SET FONT		"",RGB(0,255,255);
	TEXT			"Any key to exit",10,270;
}*/


/////////////////////////////////////////////////////////////////
//INCLUDE <debug.wdl>;

}

bmap loading_lv1 = <screen2.bmp>;  //Loading screen
panel loadingscreen1 {
	bmap = loading_lv1;   //loading screen name
	flags = refresh,d3d;
}

function load_level1()
{
	loadingscreen1.pos_x = (screen_size.x - bmap_width(loading_lv1))/2;  //centers loading screen
	loadingscreen1.pos_y = (screen_size.y - bmap_height(loading_lv1))/2;

loadingscreen1.visible = on;  //displays loading screen	
wait(3);
sleep(20);
loadingscreen1.visible = off;  //clears screen
bmap_purge(loading_lv1); 
LOAD_LEVEL <level2.wmb>;  //level name 
  
}

}

bmap loading_lv2 = <screen3.bmp>;  //Loading screen
panel loadingscreen2 {
	bmap = loading_lv2;   //loading screen name
	flags = refresh,d3d;
}

function load_level2()
{
	loadingscreen2.pos_x = (screen_size.x - bmap_width(loading_lv2))/2;  //centers loading screen
	loadingscreen2.pos_y = (screen_size.y - bmap_height(loading_lv2))/2;

loadingscreen2.visible = on;  //displays loading screen	
wait(3);
sleep(20);
loadingscreen2.visible = off;  //clears screen
bmap_purge(loading_lv2); 
LOAD_LEVEL <level3.wmb>;  //level name 
  
}

}

bmap loading_lv3 = <screen4.bmp>;  //Loading screen
panel loadingscreen3 {
	bmap = loading_lv3;   //loading screen name
	flags = refresh,d3d;
}


function load_level3()
{
	loadingscreen3.pos_x = (screen_size.x - bmap_width(loading_lv3))/2;  //centers loading screen
	loadingscreen3.pos_y = (screen_size.y - bmap_height(loading_lv3))/2;

loadingscreen3.visible = on;  //displays loading screen	
wait(3);
sleep(12);
loadingscreen3.visible = off;  //clears screen
bmap_purge(loading_lv3); 
LOAD_LEVEL <level4.wmb>;  //level name 
  
}


}

bmap loading_lv4 = <screen5.bmp>;  //Loading screen
panel loadingscreen4 {
	bmap = loading_lv4;   //loading screen name
	flags = refresh,d3d;
}


function load_level4()
{
	loadingscreen4.pos_x = (screen_size.x - bmap_width(loading_lv4))/2;  //centers loading screen
	loadingscreen4.pos_y = (screen_size.y - bmap_height(loading_lv4))/2;

loadingscreen4.visible = on;  //displays loading screen	
wait(3);
sleep(30);
loadingscreen4.visible = off;  //clears screen
bmap_purge(loading_lv4); 
LOAD_LEVEL <level5.wmb>;  //level name 
  
}



}

bmap loading_lv5 = <screen6.bmp>;  //Loading screen
panel loadingscreen5 {
	bmap = loading_lv5;   //loading screen name
	flags = refresh,d3d;
}


function load_level5()
{
	loadingscreen5.pos_x = (screen_size.x - bmap_width(loading_lv5))/2;  //centers loading screen
	loadingscreen5.pos_y = (screen_size.y - bmap_height(loading_lv5))/2;

loadingscreen5.visible = on;  //displays loading screen	
wait(3);
sleep(22);
loadingscreen5.visible = off;  //clears screen
bmap_purge(loading_lv5); 
LOAD_LEVEL <level6.wmb>;  //level name 
  
}

}

bmap loading_lv6 = <screen7.bmp>;  //Loading screen
panel loadingscreen6 {
	bmap = loading_lv6;   //loading screen name
	flags = refresh,d3d;
}


function load_level6()
{
	loadingscreen6.pos_x = (screen_size.x - bmap_width(loading_lv6))/2;  //centers loading screen
	loadingscreen6.pos_y = (screen_size.y - bmap_height(loading_lv6))/2;

loadingscreen6.visible = on;  //displays loading screen	
wait(3);
sleep(33);
loadingscreen6.visible = off;  //clears screen
bmap_purge(loading_lv6); 
LOAD_LEVEL <level7.wmb>;  //level name 
  
}

}

bmap loading_lv7 = <screen8.bmp>;  //Loading screen
panel loadingscreen7 {
	bmap = loading_lv7;   //loading screen name
	flags = refresh,d3d;
}


function load_level7()
{
	loadingscreen7.pos_x = (screen_size.x - bmap_width(loading_lv7))/2;  //centers loading screen
	loadingscreen7.pos_y = (screen_size.y - bmap_height(loading_lv7))/2;

loadingscreen7.visible = on;  //displays loading screen	
wait(3);
sleep(15);
loadingscreen7.visible = off;  //clears screen
bmap_purge(loading_lv7); 
LOAD_LEVEL <level8.wmb>;  //level name 
  
}

}

bmap loading_lv8 = <screen9.bmp>;  //Loading screen
panel loadingscreen8 {
	bmap = loading_lv8;   //loading screen name
	flags = refresh,d3d;
}


function load_level8()
{
	loadingscreen8.pos_x = (screen_size.x - bmap_width(loading_lv8))/2;  //centers loading screen
	loadingscreen8.pos_y = (screen_size.y - bmap_height(loading_lv8))/2;

loadingscreen8.visible = on;  //displays loading screen	
wait(3);
sleep(48);
loadingscreen8.visible = off;  //clears screen
bmap_purge(loading_lv8); 
LOAD_LEVEL <level9.wmb>;  //level name 
  
}

ACTION levelchange1 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level1;  //function name

} 

ACTION levelchange2 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level2;  //function name

} 

ACTION levelchange3 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level3;  //function name

} 

ACTION levelchange4 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level4;  //function name

} 

ACTION levelchange5 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level5;  //function name

} 

ACTION levelchange6 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level6;  //function name

} 

ACTION levelchange7 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level7;  //function name

} 

ACTION levelchange8 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = OFF;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level8;  //function name

} 










